@@ -1,17 +1,15 @@
-use crate::simple::{indexable::Indexable, search_index::SearchIndex};
-use std::clone::Clone;
-use std::cmp::{Eq, PartialEq};
-use std::fmt::Debug;
-use std::hash::Hash;
+use crate::simple::{Indexable, SearchIndex};
+use std::cmp::Ord;
 
 // -----------------------------------------------------------------------------
 
-impl<K: Clone + Debug + Eq + Hash + PartialEq> SearchIndex<K> {
+impl<K: Ord> SearchIndex<K> {
 
     // -------------------------------------------------------------------------
     //
-    /// An associated helper function that returns all keywords for the given
-    /// `Indexable` record.
+    /// An associated helper method that returns all keywords for the given
+    /// `Indexable` record. This function also relies on the `string_keywords`
+    /// helper method.
 
     pub(crate) fn indexable_keywords(
         &self,
@@ -23,23 +21,17 @@ impl<K: Clone + Debug + Eq + Hash + PartialEq> SearchIndex<K> {
         let strings = value.strings();
 
         // Store the individual keywords from these strings:
-        let mut keywords: Vec<String> = strings
+        strings
             // Iterate over each `String` field from the record:
             .iter()
             // Split each `String` into keywords according to the `SearchIndex`
-            // settings. Allow "use entire string as a keyword" based on user
-            // settings:
+            // settings. `string_keywords` will allow "use entire string as a
+            // keyword" if enabled in user settings:
             .map(|string| self.string_keywords(string, true))
             // Flatten the string's keywords:
             .flatten()
             // Collect all keywords into a `Vec`:
-            .collect();
-
-        // Sort, de-duplicate, and the return keywords (and full strings) to
-        // the caller:
-        keywords.sort_unstable();
-        keywords.dedup();
-        keywords
+            .collect()
 
     } // fn
 
