@@ -1,20 +1,26 @@
 mod autocomplete;
+mod internal;
+mod search;
+
+mod autocomplete_type;
+mod builder;
 mod default;
 mod deref;
 mod indexable;
 mod indexable_keywords;
 mod insert;
-mod keyword_autocomplete;
-mod keyword_search;
 mod new;
 mod remove;
 mod replace;
-mod search;
 mod search_index;
+mod search_type;
 mod string_keywords;
 mod tests;
 
 // -----------------------------------------------------------------------------
 
+pub use crate::simple::autocomplete_type::AutocompleteType;
+pub use crate::simple::builder::SearchIndexBuilder;
 pub use crate::simple::indexable::Indexable;
-pub use crate::simple::search_index::SearchIndex;
\ No newline at end of file
+pub use crate::simple::search_index::SearchIndex;
+pub use crate::simple::search_type::SearchType;
\ No newline at end of file
